##  Prioritize With Reports
Once you’ve classified your applications, use reports to prioritize modernization efforts. For example, you may want to begin with low-effort, high-impact applications or focus on a specific business capability like finance. This keeps the scope manageable and reduces risk.
Goal | Report Type | Settings | Example
---|---|---|---
Assess the strategic value and technical migration path for each application. |  Application matrix report Learn more in [Matrix Report](https://help.sap.com/docs/leanix/ea/matrix-report?locale=en-US&state=PRODUCTION&version=CLOUD). |  Axes:
  * x-axis: TIME Classification
  * y-axis: 6R Strategy

Filters:
  * Lifecycle: Plan, Phase In, Active, Phase Out
  * Hosting Type: On Premise
  * Time Classification: Invest or Migrate

|  ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9454a66db1c044e78e09eb29a8914235_LowRes.png)
  * Retire and Migrate: Candidates for decommissioning soon.
  * Rehost and Invest: Low-effort modernization, keep and optimize.
  * Rearchitect and Migrate: Higher complexity, plan for later phases.
  * Replatform and Invest: Good candidates for an incremental modernization approach.


Identify quick wins for your modernization initiative. |  Application portfolio report Learn more in [Portfolio Report](https://help.sap.com/docs/leanix/ea/portfolio-report?locale=en-US&state=PRODUCTION&version=CLOUD). |  Axes:
  * x-axis: 6R Strategy
  * y-axis: Business Criticality

Circle Size:
  * Number of Fact Sheets

Filters:
  * Lifecycle: Plan, Phase In, Active, Phase Out
  * Hosting Type: On Premise
  * Time Classification: Invest or Migrate

|  ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio6a5652736a42448888cb67e74c4cb3eb_LowRes.png)
  * Rehost and Retire: Higher risk, even for apps that aren't mission critical. Needs attention.
  * Rearchitect: High effort for critical apps, careful planning is required.
  * Replatform, Retain, Repurchase: Low-risk modernization opportunities. Prioritize the mission-critical ones for quick wins.




